jactorch.functional.linalg
==========================

.. automodule:: jactorch.functional.linalg

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      normalize
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: normalize


